@@ -3,8 +3,22 @@
 Batch Job CLI entry points.
 """
 import click
-from reV.generation.cli_gen import main
+
 from reV.batch.batch import BatchJob
+from rex.utilities.cli_dtypes import STR
+
+
+@click.group()
+@click.option('--name', '-n', default='reV-batch', type=STR,
+              help='reV batch name, by default "reV-batch".')
+@click.option('-v', '--verbose', is_flag=True,
+              help='Flag to turn on debug logging. Default is not verbose.')
+@click.pass_context
+def main(ctx, name, verbose):
+    """reV Batch Command Line Interface"""
+    ctx.ensure_object(dict)
+    ctx.obj['VERBOSE'] = verbose
+    ctx.obj['NAME'] = name
 
 
 @main.command()
