@@ -14,7 +14,7 @@ from reV.pipeline.status import Status
 
 from rex.utilities.cli_dtypes import STR, STRLIST, PATHLIST, INT
 from rex.utilities.loggers import init_mult
-from rex.utilities.execution import SubprocessManager, SLURM
+from rex.utilities.execution import SLURM
 
 logger = logging.getLogger(__name__)
 
@@ -243,19 +243,20 @@ def get_slurm_cmd(name, my_file, group_params, verbose=False):
     """
     # make a cli arg string for direct() in this module
     main_args = ('-n {name} '
-                 '-f {my_file} '
                  '{v}'
-                 .format(name=SubprocessManager.s(name),
-                         my_file=SubprocessManager.s(my_file),
+                 .format(name=SLURM.s(name),
+                         my_file=SLURM.s(my_file),
                          v='-v ' if verbose else '',
                          ))
 
-    collect_args = '-gp {} '.format(SubprocessManager.s(group_params))
+    collect_args = '-gp {} '.format(SLURM.s(group_params))
 
     # Python command that will be executed on a node
     # command strings after cli v7.0 use dashes instead of underscores
-    cmd = ('python -m reV.handlers.cli_multi_year {} multi-year-groups {}'
-           .format(main_args, collect_args))
+
+    cmd = ('python -m reV.handlers.cli_multi_year {} direct -f {} '
+           'multi-year-groups {}'
+           .format(main_args, SLURM.s(my_file), collect_args))
     logger.debug('Creating the following command line call:\n\t{}'
                  .format(cmd))
     return cmd
